pub struct PortRef<M> { /* private fields */ }Expand description
A reference to a remote port. All messages passed through PortRefs will be serialized. PortRefs are always streaming.
Implementations
Sourceimpl<M: RemoteMessage> PortRef<M>
impl<M: RemoteMessage> PortRef<M>
Sourcepub fn attest(port_addr: PortAddr) -> Self
pub fn attest(port_addr: PortAddr) -> Self
The caller attests that the provided port address identifies a
reachable typed port for message type M.
Sourcepub fn attest_reducible(
port_addr: PortAddr,
reducer_spec: Option<ReducerSpec>,
streaming_opts: StreamingReducerOpts,
) -> Self
pub fn attest_reducible( port_addr: PortAddr, reducer_spec: Option<ReducerSpec>, streaming_opts: StreamingReducerOpts, ) -> Self
The caller attests that the provided port address identifies a
reachable typed port for message type M.
Sourcepub fn attest_handler_port(actor: &ActorAddr) -> Self
pub fn attest_handler_port(actor: &ActorAddr) -> Self
The caller attests that the provided actor exposes a reachable handler
port for message type M.
Sourcepub fn reducer_spec(&self) -> &Option<ReducerSpec>
pub fn reducer_spec(&self) -> &Option<ReducerSpec>
The typehash of this port’s reducer, if any. Reducers may be used to coalesce messages sent to a port.
Sourcepub fn into_port_addr(self) -> PortAddr
pub fn into_port_addr(self) -> PortAddr
Convert this PortRef into its corresponding port address.
Sourcepub fn into_once(self) -> OncePortRef<M>
pub fn into_once(self) -> OncePortRef<M>
coerce it into OncePortRef so we can send messages to this port from APIs requires OncePortRef.
Sourcepub fn post_serialized(&self, cx: &impl Actor, headers: Flattrs, message: Any)
pub fn post_serialized(&self, cx: &impl Actor, headers: Flattrs, message: Any)
Post a serialized message to this port, provided a sending capability, such as
[crate::actor::Instance].
Sourcepub fn into_sink<C: Actor>(self, cx: C) -> PortSink<C, M>
pub fn into_sink<C: Actor>(self, cx: C) -> PortSink<C, M>
Convert this port into a sink that can be used to send messages using the given capability.
Sourcepub fn get_return_undeliverable(&self) -> bool
pub fn get_return_undeliverable(&self) -> bool
Get whether or not messages sent to this port that are undeliverable should be returned to the sender.
Sourcepub fn return_undeliverable(&mut self, return_undeliverable: bool)
pub fn return_undeliverable(&mut self, return_undeliverable: bool)
Set whether or not messages sent to this port that are undeliverable should be returned to the sender.